==> golem-0.0.3.tar.gz: golem-0.0.3/src/pixmap.h <==
/*-
 * Copyright (c) 2001 Jordan DeLong
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of contributors may be
 *    used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
#ifndef _PIXMAP_H
#define _PIXMAP_H

/*
 * we keep our pixmaps for decoration in this struct, thus allowing more
 * than one decoration unit to use the same pixmap.
 */
typedef struct pixmap {
	char	*ident;		/* the name of this pixmap (from the rc file) */
	char	*xpmfn;		/* filename of the pixmap */

	Pixmap	*pixmaps;	/* the pixmap itself: array w/ one per screen */
	Pixmap	*shapemasks;	/* the shape of the pixmap: array per screen */

	int	width, height;	/* pixmap dimensions */

	struct pixmap *next;	/* list pointer */
} pixmap_t;

void pixmap_shutdown();
pixmap_t *pixmap_add(char *ident, char *xpmfn);
pixmap_t *pixmap_ident(char *ident);
int pixmap_getpixmaps(screen_t *screen_list);

#endif

==> golem_0.0.5.orig.tar.gz: golem-0.0.5/src/pixmap.h <==
/*-
 * Copyright (c) 2001 Jordan DeLong
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of contributors may be
 *    used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
#ifndef PIXMAP_H
#define PIXMAP_H

/*
 * we keep our pixmaps for decoration in this struct, thus allowing more
 * than one decoration unit to use the same pixmap.
 */
struct pixmap {
	char	*ident;		/* the name of this pixmap (from the rc file) */
	char	*xpmfn;		/* filename of the pixmap */

	Pixmap	*pixmaps;	/* the pixmap itself: array w/ one per screen */
	Pixmap	*shapemasks;	/* the shape of the pixmap: array per screen */

	int	width, height;	/* pixmap dimensions */

	SLIST_ENTRY(pixmap) p_list;
};

void pixmap_shutdown();
pixmap_t *pixmap_add(char *ident, char *xpmfn);
pixmap_t *pixmap_ident(char *ident);
int pixmap_getpixmaps();

#endif
